@@ -982,7 +982,7 @@ def isclose(a, b, rtol=1.0e-5, atol=1.0e-8, equal_nan=False):
     # deal with signed inf values. this will make an array inf_eq of 0's
     # except where inf values have the same sign.
     both_infs = bitwise_and(a_inf, b_inf)
-    inf_signs_eq = eq(a_inf * sgn(a), b_inf * sgn(b))
+    inf_signs_eq = eq(a_inf * sign(a), b_inf * sign(b))
     inf_eq = bitwise_and(both_infs, inf_signs_eq)
 
     # now create the potential result combining close and inf_eq
@@ -1092,9 +1092,19 @@ def log1p(a):
 
 
 @scalar_elemwise
+def sign(a):
+    """sign of a"""
+
+
 def sgn(a):
     """sign of a"""
 
+    warnings.warn(
+        "sgn is deprecated and will stop working in the future, use sign instead.",
+        FutureWarning,
+    )
+    return sign(a)
+
 
 @scalar_elemwise
 def ceil(a):
@@ -3038,6 +3048,7 @@ __all__ = [
     "log10",
     "log1p",
     "sgn",
+    "sign",
     "ceil",
     "floor",
     "trunc",
